cordova.define("com.mysoft.maudioplayer.MAudioPlayer", function(require, exports, module) {
var exec = require('cordova/exec');

function MAudioPlayer() {

}

var getDataType = function (data) {
    var type = Object.prototype.toString.call(data).slice(8, -1);
    return type;
}

var isEmptyValue = function (value) {
    var type;
    if (value == null) { // 等同于 value === undefined || value === null
        return true;
    }
    type = getDataType(value);
    switch (type) {
        case 'String':
            return !value.trim().length;
        case 'Array':
            return !value.length;
        case 'Object':
            return !Object.keys(value).length; // 普通对象使用 for...in 判断，有 key 即为 false
        default:
            return false; // 其他对象均视作非空
    }
};
    
// 播放音频
MAudioPlayer.prototype.playCallback = function (cb) {
    return function (result) {
        // start 1
        // progress 2
        // error 3
        // finish 4
        var code = result[0];
        switch (code) {
            case 1: {
                if (cb != null && cb.start != undefined && cb.start != null) {
                    var obj = result[1];
                    cb.start(obj);
                }
            }
                break;
            case 2: {
                if (cb != null && cb.progress != undefined && cb.progress != null) {
                    var obj = result[1];
                    var current = result[2];
                    var total = result[3];
                    cb.progress(obj, current, total);
                }
            }
                break;
            case 3: {
                if (cb != null && cb.error != undefined && cb.error != null) {
                    var error = result[1];
                    cb.error(error);
                }
            }
                break;
            case 4: {
                if (cb != null && cb.finish != undefined && cb.finish != null) {
                    cb.finish();
                }
            }
                break;
            default: {
                if (cb && cb.error) {
                    cb.error(result);
                }
            }
                break;
        }
    };
}
// 播放单个音频文件
MAudioPlayer.prototype.playSingleFile = function (file, callback) {
    if (getDataType(file) !== "String" || isEmptyValue(file)) {
        if (callback && callback.error) {
            callback.error({'errCode': 1001, 'errMsg': '参数错误:file:' + file});
        }
        return;
    }
    exec(this.playCallback(callback), this.playCallback(callback), 'MAudioPlayer', 'playSingleFile', [file]);
};

// 播放多个音频文件
MAudioPlayer.prototype.playMultiFiles = function (files, callback, timerInterval) {
    if (getDataType(files) !== "Array" || isEmptyValue(files)) {
        if (callback && callback.error) {
            callback.error({'errCode': 1001, 'errMsg': '参数错误:files:' + files});
        }
        return;
    }
    exec(this.playCallback(callback), this.playCallback(callback), 'MAudioPlayer', 'playMultiFiles', [files, timerInterval]);
};

// 取消播放音频
MAudioPlayer.prototype.cancelPlay = function (success, error) {
    exec(success, error, 'MAudioPlayer', 'cancelPlay', []);
};

var audioPlayer = new MAudioPlayer();
module.exports = audioPlayer;
});
