-- ---------------------------------------------------------------------------------------------------
-- 由于所有数据都是要支持离线的，所以直接将本地app当成一套sql玩吧，搞起（SQLite）
-- COLLATE NOCASE:不区分大小写
-- ---------------------------------------------------------------------------------------------------
-- 1.筛选器部分需要的表
-- 负责人表，负责人直接在k_work中反查
-- 问题分类表(kf_task_problem)
CREATE TABLE IF NOT EXISTS kf_task_problem
(
    `id` CHAR(36) PRIMARY KEY NOT NULL,
    `task_id` char(36) DEFAULT NULL COLLATE NOCASE, -- COMMENT '任务id,一个任务可以有多个问题描述'
    `class_id` char(36) DEFAULT NULL COLLATE NOCASE, -- COMMENT '问题分类ID'
    `class_name` varchar(50) DEFAULT '',    -- COMMENT '问题分类简称'
    `class_full_name` varchar(500) DEFAULT NULL,    -- COMMENT '问题分类全称'
    `problem_name` varchar(128) DEFAULT '', -- 问题描述，一个work可以有多个对应(列表页字段；对应k_task_problem表中的problem_name字段)
    `remark` varchar(150) DEFAULT '' -- COMMENT '问题描述补充说明'
)
-- 楼栋表(kf_building)
CREATE TABLE IF NOT EXISTS kf_building
(
    `id` CHAR(36) NOT NULL,
    `proj_id` CHAR(36) DEFAULT '' COLLATE NOCASE, -- , -- COMMENT '项目id'
    `name` varchar(50) DEFAULT NULL, -- COMMENT '分区名+楼栋名'
    `sort` int(8) DEFAULT 0, -- COMMENT '排序'
    PRIMARY KEY (`id`)
)
-- 楼栋单元表(kf_building_unit)
CREATE TABLE IF NOT EXISTS kf_building_unit
(
    `id` CHAR(36) NOT NULL,
    `building_id` CHAR(36) DEFAULT '' COLLATE NOCASE, -- COMMENT '楼栋id'
    `building_name` varchar(50) DEFAULT NULL, -- COMMENT '楼栋名,冗余字段,方便前端查询'
    `unit` varchar(50) DEFAULT NULL, -- COMMENT '单元'
    `sort` int(8) DEFAULT 0, -- COMMENT '排序'
    PRIMARY KEY (`id`)
)
CREATE INDEX IF NOT EXISTS idx_building_id ON kf_building_unit (building_id);
-- 房间表(kf_room)
CREATE TABLE IF NOT EXISTS kf_room
(
    `id` CHAR(36) NOT NULL,
    `building_id` CHAR(36) DEFAULT '' COLLATE NOCASE, -- COMMENT '楼栋id'
    `proj_id` CHAR(36) DEFAULT '' COLLATE NOCASE, -- COMMENT '项目id'
    `unit` CHAR(36) DEFAULT '', -- COMMENT '单元'
    `floor` varchar(20) DEFAULT null , -- COMMENT '楼层'
    `name` varchar(50) DEFAULT NULL , -- COMMENT '房间名'
    `room_no` varchar(50) DEFAULT NULL , -- COMMENT '房号'
    `sort` int(11) DEFAULT 0 , -- COMMENT '排序'
    PRIMARY KEY (`id`)
)
-- 默认排序，不需要表，写死就好：promise_deadline、send_back_times、work_code、booking_time
-- 2.列表数据
-- 任务主表(kf_work)  fixme还差筛选器条件
CREATE TABLE IF NOT EXISTS kf_work
(
    `id` char(36) not null,
    `proj_id` char(36) not null DEFAULT '' COLLATE NOCASE,            -- 项目ID
    `tenant_id`  char(36) not null DEFAULT '' COLLATE NOCASE,         -- 租户ID
    `building_id` char(36) not null DEFAULT '' COLLATE NOCASE,        -- 楼栋id
    `unit` varchar(50) DEFAULT NULL,                            -- 单元(因为有独栋楼是没有单元的)
    `floor` varchar(50) DEFAULT NULL,                           -- 楼层
    `room_id` varchar(50) DEFAULT NULL COLLATE NOCASE,          -- 房间id
    `room_name`  varchar(100) DEFAULT NULL,                     -- 维修对象：分区楼栋单元-楼层-房号
    `task_id` char(36) not null DEFAULT '' COLLATE NOCASE,      -- task表主键id
    `problem_position` varchar(255) not null DEFAULT '',        -- 问题部位名称
    `subject`  TEXT,                        -- 任务描述(详情页；对应k_work表的task_remark字段)
    `status` varchar(25) not null DEFAULT '',                   -- 整改状态:'待指派','待整改','已整改','已通过','被退回'
    `work_code` varchar(50) DEFAULT NULL,                       -- COMMENT '派工单号'
    `contractor_user_id`  char(36) DEFAULT '',                  -- 负责任id,对应k_work表中的contractor_user_id字段
    `contractor_user_name`  char(36) DEFAULT '',                -- 负责人name
    `maintainer_id` char(36) DEFAULT NULL COLLATE NOCASE,       -- 承建商id	默认为第三方责任方 如为空则为承建商
    `maintainer_name` varchar(100) DEFAULT NULL,                -- 承建商名称
    `register_time`         DATETIME,                           -- 登记时间(k_task表的accept_time)
    `assign_time `          DATETIME,                           -- 指派时间
    `booking_time`          DATETIME,                           -- 预约上门时间
    `promise_deadline`      DATETIME                            -- 整改时限(详情页显示和计算超时)
    `repair_time`           DATETIME,                           -- 整改时间
    `repair_remark` varchar(200) DEFAULT '',                    -- 整改说明
    `repair_user_id` char(36) DEFAULT '' COLLATE NOCASE,        -- 整改人
    `timeout_reason` varchar(200) DEFAULT '',                   -- 整改超时原因
    `timeout_reason_remark` varchar(200) DEFAULT '',            -- 整改超时原因补充说明
    `send_back_user_id` char(36) DEFAULT '' COLLATE NOCASE,     -- 退回人
    `send_back_date`        DATETIME,                           -- 工程师退回时间
    `send_back_times` tinyint(1) DEFAULT 0,                     -- 工程师退回次数
    `send_back_reason` varchar(200) DEFAULT '',                 -- 工程师退回原因
    `send_back_reason_remark` varchar(200) DEFAULT '',          -- 工程师退回原因补充说明
    `is_update` tinyint(1) DEFAULT 0,               -- 是否为新任务,红点标识
    `is_discard`          INTEGER DEFAULT 0,        -- 是否作废,1:作废,0:非作废
    `discard_time`          DATETIME,               -- 作废时间
    `send_back_developer_time`          DATETIME,    -- 退回开发商时间
    `is_send_back` tinyint(1) DEFAULT 0,            -- 是否退回开发商
    `is_delete` tinyint(1) DEFAULT 0,               -- 是否删除（1:已删除;0:未删除）
    PRIMARY KEY (`id`)
);
-- 3.问题详情
-- 整改前后图片关联表(kf_work_images;type:0为整改前图片，1为整改后图片)
CREATE TABLE IF NOT EXISTS kf_work_images
(
   id                   TEXT PRIMARY KEY NOT NULL COLLATE NOCASE,
   work_id              TEXT COLLATE NOCASE,
   proj_id              TEXT COLLATE NOCASE,
   img_url              TEXT,
   img_localpath        TEXT,
   sort                 INTEGER DEFAULT 0,
   type                 TEXT
);
